@@ -4,7 +4,7 @@ import math
 import json
 import io
 import time
-from mgz import header, fast, enums, const
+from mgz import header, fast, enums, const, summary
 from mgz.enums import OperationEnum
 from construct import Byte
 from collections import OrderedDict
@@ -579,6 +579,7 @@ def guess_strategy(players):
     return player_strategies
 
 def print_to_csv(players,
+                 summary,
                  header,
                  civs,
                  player_strategies,
@@ -591,7 +592,7 @@ def print_to_csv(players,
     #output to std with information
     ret_string = ""
     if header is not None:
-        ret_string += 'Map, ' + const.DE_MAP_NAMES[header.de.selected_map_id] + "\n"
+        ret_string += 'Map, ' + summary.get_map()["name"] + "\n"
     #go through once to get the game data before doing individual player stuff
     player_data = {}
     team_dict = {}
@@ -603,7 +604,7 @@ def print_to_csv(players,
         player_name = header.de.players[player_num].name.value.decode()
         player_civ = civs[header.de.players[player_num].civ_id]
         player_color = Color(header.de.players[player_num].color_id).name
-        player_team = header.de.players[player_num].team_id
+        player_team = header.de.players[player_num].resolved_team_id
         if player_team not in team_dict:
           team_dict[player_team] = len(team_dict)+1
         player_team = team_dict[player_team]
@@ -682,23 +683,23 @@ def print_to_csv(players,
                 tribute.data["wood"] > 0  or
                 tribute.data["gold"] > 0  or
                 tribute.data["stone"] > 0) :
-                tribute_strings.append(f'{player_data[player_num]["name"]}, '
+                tribute_strings.append((tribute.timestamp,
+                        f'{player_data[player_num]["name"]}, '
                         f'{header.de.players[tribute.data["player_id_to"]-1].name.value.decode()}, '
                         f'{output_time(tribute.timestamp)}, '
                         f'{tribute.data["food"]}, '
                         f'{tribute.data["wood"]}, '
                         f'{tribute.data["gold"]}, '
-                        f'{tribute.data["stone"]}\n')
+                        f'{tribute.data["stone"]}\n'))
         player_num += 1
     ret_string += f'\nName, Civ, Color, Team, Victory State, Feudal Time, Castle Time, Imp Time\n'
     for player in player_data.values():
         ret_string += f'{player["name"]}, {player["civ"]}, {player["color"]}, {player["team"]}, {player["victory_state"]}, {player["feudal"]}, {player["castle"]} ,{player["imp"]}\n'
     if tribute_strings:
-        #lazy hacky sort tributes since i dont want to change the code rn
-        tribute_strings = sorted(tribute_strings, key=lambda x: time.mktime(time.strptime(x.split(',')[2]," %M:%S")))
+        tribute_strings = sorted(tribute_strings, key=lambda x:x[0])
         ret_string += "\nTribute from Player, To Player, Time, Food, Wood, Gold, Stone\n"
         for tribute in tribute_strings:
-          ret_string += tribute
+          ret_string += tribute[1]
     ret_string += f'\nDuration, {output_time(last_timestamp)}\n'
 
     return ret_string
@@ -730,4 +731,6 @@ def print_events(players, header, civs, player_strategies):
 if __name__ == '__main__':
     players, header, civs, loser_id = parse_replay(sys.argv[1])
     player_strategies = guess_strategy(players)
-    print(print_to_csv(players, header, civs, player_strategies, False, False, False, False, False, False))
+    with open(sys.argv[1], "rb") as handle:
+      game_summary = summary.FullSummary(handle)
+    print(print_to_csv(players, game_summary, header, civs, player_strategies, False, False, False, False, False, False))
